@@ -1,28 +1,27 @@
 /* Grapheme cluster break function.
-   Copyright (C) 2010-2016 Free Software Foundation, Inc.
+   Copyright (C) 2010-2022 Free Software Foundation, Inc.
    Written by Ben Pfaff <blp@cs.stanford.edu>, 2010.
 
-   This program is free software: you can redistribute it and/or
-   modify it under the terms of either:
+   This file is free software.
+   It is dual-licensed under "the GNU LGPLv3+ or the GNU GPLv2+".
+   You can redistribute it and/or modify it under either
+     - the terms of the GNU Lesser General Public License as published
+       by the Free Software Foundation; either version 3, or (at your
+       option) any later version, or
+     - the terms of the GNU General Public License as published by the
+       Free Software Foundation; either version 2, or (at your option)
+       any later version, or
+     - the same dual license "the GNU LGPLv3+ or the GNU GPLv2+".
 
-     * the GNU Lesser General Public License as published by the Free
-       Software Foundation; either version 3 of the License, or (at your
-       option) any later version.
-
-   or
-
-     * the GNU General Public License as published by the Free
-       Software Foundation; either version 2 of the License, or (at your
-       option) any later version.
-
-   or both in parallel, as here.
-   This program is distributed in the hope that it will be useful,
+   This file is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Lesser General Public License for more details.
+   Lesser General Public License and the GNU General Public License
+   for more details.
 
-   You should have received a copy of the GNU Lesser General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   You should have received a copy of the GNU Lesser General Public
+   License and of the GNU General Public License along with this
+   program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 #include <config.h>
 
@@ -56,19 +55,22 @@
    /* GB8 */                                                            \
    ((A) == GBP_LVT || (A) == GBP_T) && (B) == GBP_T ? false :           \
                                                                         \
-   /* GB8a */								\
-   (A) == GBP_RI && (B) == GBP_RI ? false :				\
-									\
    /* GB9 */                                                            \
-   (B) == GBP_EXTEND ? false :                                          \
+   (B) == GBP_EXTEND || (B) == GBP_ZWJ ? false :                        \
                                                                         \
    /* GB9a */                                                           \
    (B) == GBP_SPACINGMARK ? false :                                     \
                                                                         \
    /* GB9b */                                                           \
-   (A) == GBP_PREPEND ? false                                           \
+   (A) == GBP_PREPEND ? false :                                         \
                                                                         \
-   /* GB10 */                                                           \
+   /* GB10 -- incomplete */                                             \
+   ((A) == GBP_EB || (A) == GBP_EBG) && (B) == GBP_EM ? false :         \
+                                                                        \
+   /* GB11 */                                                           \
+   (A) == GBP_ZWJ && ((B) == GBP_GAZ || (B) == GBP_EBG) ? false         \
+                                                                        \
+   /* GB999 */                                                          \
    : true)
 
 #define UC_GRAPHEME_BREAKS_FOR(A)                                       \
@@ -84,9 +86,14 @@
    | (UC_IS_GRAPHEME_BREAK(A, GBP_T)           << GBP_T)                \
    | (UC_IS_GRAPHEME_BREAK(A, GBP_LV)          << GBP_LV)               \
    | (UC_IS_GRAPHEME_BREAK(A, GBP_LVT)         << GBP_LVT)              \
-   | (UC_IS_GRAPHEME_BREAK(A, GBP_RI)          << GBP_RI))
+   | (UC_IS_GRAPHEME_BREAK(A, GBP_RI)          << GBP_RI)               \
+   | (UC_IS_GRAPHEME_BREAK(A, GBP_ZWJ)         << GBP_ZWJ)              \
+   | (UC_IS_GRAPHEME_BREAK(A, GBP_EB)          << GBP_EB)               \
+   | (UC_IS_GRAPHEME_BREAK(A, GBP_EM)          << GBP_EM)               \
+   | (UC_IS_GRAPHEME_BREAK(A, GBP_GAZ)         << GBP_GAZ)              \
+   | (UC_IS_GRAPHEME_BREAK(A, GBP_EBG)         << GBP_EBG))
 
-static const unsigned short int gb_table[13] =
+static const unsigned long int gb_table[18] =
   {
     UC_GRAPHEME_BREAKS_FOR(0),  /* GBP_OTHER */
     UC_GRAPHEME_BREAKS_FOR(1),  /* GBP_CR */
@@ -101,6 +108,11 @@ static const unsigned short int gb_table[13] =
     UC_GRAPHEME_BREAKS_FOR(10), /* GBP_LV */
     UC_GRAPHEME_BREAKS_FOR(11), /* GBP_LVT */
     UC_GRAPHEME_BREAKS_FOR(12), /* GBP_RI */
+    UC_GRAPHEME_BREAKS_FOR(13), /* GBP_ZWJ */
+    UC_GRAPHEME_BREAKS_FOR(14), /* GBP_EB */
+    UC_GRAPHEME_BREAKS_FOR(15), /* GBP_EM */
+    UC_GRAPHEME_BREAKS_FOR(16), /* GBP_GAZ */
+    UC_GRAPHEME_BREAKS_FOR(17), /* GBP_EBG */
   };
 
 bool
